@@ -197,10 +197,7 @@ EnvironmentWidget::EnvironmentWidget(QWidget *parent, Type type, QWidget *additi
 
     auto horizontalLayout = new QHBoxLayout();
     horizontalLayout->setContentsMargins(0, 0, 0, 0);
-    auto tree = new Utils::TreeView(this);
-    connect(tree, &QAbstractItemView::activated,
-            tree, [tree](const QModelIndex &idx) { tree->edit(idx); });
-    d->m_environmentView = tree;
+    d->m_environmentView = new Utils::TreeView(this);
     d->m_environmentView->setModel(d->m_model);
     d->m_environmentView->setMinimumHeight(400);
     d->m_environmentView->setRootIsDecorated(false);
@@ -240,6 +237,7 @@ EnvironmentWidget::EnvironmentWidget(QWidget *parent, Type type, QWidget *additi
     buttonLayout->addWidget(d->m_toggleButton);
     connect(d->m_toggleButton, &QPushButton::clicked, this, [this] {
         d->m_model->toggleVariable(d->m_environmentView->currentIndex());
+        d->m_editor.setEnvironmentItems(d->m_model->userChanges());
         updateButtons();
     });
 
@@ -335,6 +333,7 @@ void EnvironmentWidget::setBaseEnvironmentText(const QString &text)
 
 Utils::EnvironmentItems EnvironmentWidget::userChanges() const
 {
+    forceUpdateCheck();
     return d->m_model->userChanges();
 }
 
@@ -355,6 +354,11 @@ void EnvironmentWidget::expand()
     d->m_detailsContainer->setState(Utils::DetailsWidget::Expanded);
 }
 
+void EnvironmentWidget::forceUpdateCheck() const
+{
+    d->m_editor.forceUpdateCheck();
+}
+
 void EnvironmentWidget::updateSummaryText()
 {
     // The summary is redundant with the text edit, so we hide it on expansion.
@@ -363,7 +367,10 @@ void EnvironmentWidget::updateSummaryText()
         return;
     }
 
-    Utils::EnvironmentItems list = d->m_model->userChanges();
+    Utils::EnvironmentItems list
+            = Utils::filtered(d->m_model->userChanges(), [](const EnvironmentItem &it) {
+        return it.operation != Utils::EnvironmentItem::Comment;
+    });
     Utils::EnvironmentItem::sort(&list);
 
     QString text;
@@ -387,6 +394,8 @@ void EnvironmentWidget::updateSummaryText()
             case Utils::EnvironmentItem::SetDisabled:
                 text.append(Tr::tr("Set <a href=\"%1\"><b>%1</b></a> to <b>%2</b> [disabled]").arg(item.name.toHtmlEscaped(), item.value.toHtmlEscaped()));
                 break;
+            case Utils::EnvironmentItem::Comment:
+                break;
             }
         }
     }
