@@ -72,9 +72,7 @@ const std::vector<PropertyName> blockListSlots = {"childAt",
                                                   "inputMethodQuery",
                                                   "positionAt",
                                                   "positionToRectangle",
-                                                  "isRightToLeft"
-
-};
+                                                  "isRightToLeft"};
 
 const std::vector<PropertyName> priorityListSignals = {"clicked",
                                                        "doubleClicked",
@@ -99,7 +97,8 @@ const std::vector<PropertyName> priorityListSignals = {"clicked",
                                                        "enabledChanged",
                                                        "visibleChanged",
                                                        "opacityChanged",
-                                                       "rotationChanged"};
+                                                       "rotationChanged",
+                                                       "positionChanged"};
 
 const std::vector<PropertyName> priorityListProperties = {"opacity",
                                                           "checked",
@@ -164,8 +163,8 @@ std::vector<PropertyName> properityLists()
     return result;
 }
 
-PropertyTreeModel::PropertyTreeModel(ConnectionView *parent)
-    : QAbstractItemModel(parent), m_connectionView(parent)
+PropertyTreeModel::PropertyTreeModel(ConnectionView *view)
+    : m_connectionView(view)
 {}
 
 void PropertyTreeModel::resetModel()
@@ -494,7 +493,9 @@ const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredPropertyName
         return returnValue;
 
     if (m_type == SignalType) {
-        returnValue = sortedAndFilteredSignalNames(modelNode.metaInfo());
+        auto list = sortedAndFilteredSignalNames(modelNode.metaInfo());
+        returnValue = getDynamicSignals(modelNode);
+        std::move(list.begin(), list.end(), std::back_inserter(returnValue));
     } else if (m_type == SlotType) {
         returnValue = sortedAndFilteredSlotNames(modelNode.metaInfo());
     } else {
@@ -549,6 +550,18 @@ const std::vector<PropertyName> PropertyTreeModel::getDynamicProperties(
     return Utils::sorted(std::vector<PropertyName>(filtered.begin(), filtered.end()));
 }
 
+const std::vector<PropertyName> PropertyTreeModel::getDynamicSignals(const ModelNode &modelNode) const
+{
+    QList<PropertyName> list = Utils::transform(modelNode.dynamicProperties(),
+                                                [](const AbstractProperty &property) {
+                                                    if (property.isSignalDeclarationProperty())
+                                                        return property.name();
+
+                                                    return PropertyName(property.name() + "Changed");
+                                                });
+    return Utils::sorted(std::vector<PropertyName>(list.begin(), list.end()));
+}
+
 const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredPropertyNames(
     const NodeMetaInfo &metaInfo, bool recursive) const
 {
@@ -558,8 +571,7 @@ const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredPropertyName
 
                                         const PropertyName name = metaInfo.name();
 
-                                        if (!m_includeDotPropertiesOnFirstLevel
-                                            && name.contains("."))
+                                        if (!m_includeDotPropertiesOnFirstLevel && name.contains("."))
                                             return false;
 
                                         return filterProperty(name, metaInfo, recursive);
@@ -592,8 +604,8 @@ const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredPropertyName
     return checkedPriorityList;
 }
 
-const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredSignalNames(
-    const NodeMetaInfo &metaInfo, bool recursive) const
+std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredSignalNames(const NodeMetaInfo &metaInfo,
+                                                                          bool recursive)
 {
     Q_UNUSED(recursive);
 
@@ -613,15 +625,14 @@ const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredSignalNames(
     std::set<PropertyName> set(std::make_move_iterator(sorted.begin()),
                                std::make_move_iterator(sorted.end()));
 
-    auto checkedPriorityList = Utils::filtered(priorityListSignals,
-                                               [&set](const PropertyName &name) {
-                                                   auto it = set.find(name);
-                                                   const bool b = it != set.end();
-                                                   if (b)
-                                                       set.erase(it);
+    auto checkedPriorityList = Utils::filtered(priorityListSignals, [&set](const PropertyName &name) {
+        auto it = set.find(name);
+        const bool b = it != set.end();
+        if (b)
+            set.erase(it);
 
-                                                   return b;
-                                               });
+        return b;
+    });
 
     //const int priorityLength = checkedPriorityList.size(); We eventually require this to get the prioproperties
 
@@ -634,8 +645,8 @@ const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredSignalNames(
     return checkedPriorityList;
 }
 
-const std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredSlotNames(
-    const NodeMetaInfo &metaInfo, bool recursive) const
+std::vector<PropertyName> PropertyTreeModel::sortedAndFilteredSlotNames(const NodeMetaInfo &metaInfo,
+                                                                        bool recursive)
 {
     Q_UNUSED(recursive);
 
@@ -872,12 +883,13 @@ QString PropertyListProxyModel::parentName() const
     return m_treeModel->data(m_parentIndex, PropertyTreeModel::UserRoles::PropertyNameRole).toString();
 }
 
-PropertyTreeModelDelegate::PropertyTreeModelDelegate(ConnectionView *parent) : m_model(parent)
+PropertyTreeModelDelegate::PropertyTreeModelDelegate(ConnectionView *view)
+    : m_model(view)
 {
-    connect(&m_nameCombboBox, &StudioQmlComboBoxBackend::activated, this, [this]() {
+    connect(&m_nameCombboBox, &StudioQmlComboBoxBackend::activated, this, [this] {
         handleNameChanged();
     });
-    connect(&m_idCombboBox, &StudioQmlComboBoxBackend::activated, this, [this]() {
+    connect(&m_idCombboBox, &StudioQmlComboBoxBackend::activated, this, [this] {
         handleIdChanged();
     });
 
